@@ -9,12 +9,13 @@ from functools import lru_cache
 from os.path import abspath, dirname
 # import awswrangler as wr
 from typing import Dict
+from boto3.session import Session
+from packaging import version
 
 import findspark
 import tomlkit
 from black import FileMode, format_str
 
-
 REQUIRED_PARAM = ["s3-staging-dir", "cluster-name", "stage", "region"]
 DEFAULT_TOML_PATH = "./pyproject.toml"
 
@@ -24,10 +25,23 @@ DEFAULT_CONFIG_TEMPLATE = {
     "stage": "dev",
     "date-time": "%Y-%m-%dT%H-%M-%S",
     "region": "eu-west-1",
-    "s3_patch_dir": "./data/mock/s3",
-    "spark_version": "2.4.5",
+    "s3-patch-dir": "./data/mock/s3",
+    "spark-version": "2.4.5",
 }
 
+# s3_patch_dir
+# spark_version
+
+INPUT_TYPES = {
+        "cluster-name": str,
+        "s3-staging-dir": str ,
+        "stage": str,
+        "date-time": str ,
+        "s3-patch-dir": str,
+        "spark-version": str ,
+}
+    
+
 DEFAULT_DEPENDENCIES = dict(
     Cython="0.29.24",
     pybind11="1.0.0",
@@ -91,7 +105,7 @@ def get_static_files_dir():
 
 def get_mock_s3_path():
     """Returns the local s3 mock directory."""
-    mock_dir = get_config_attr("s3_patch_dir")
+    mock_dir = get_config_attr("s3-patch-dir")
     if mock_dir.endswith("/"):
         mock_dir = mock_dir[:-1]
     return mock_dir
@@ -129,6 +143,60 @@ def create_git_ignore():
         append_git_ignore(git_ignore_path)
 
 
+@lru_cache()
+def get_avalible_s3_regions():
+    session = Session()
+    s3_regions = session.get_available_regions('s3')
+    return s3_regions
+
+
+def validate_input(key,value):
+    
+    if key in INPUT_TYPES:
+        if type(value) != INPUT_TYPES[key]:
+            raise ValueError(f"'{key}' must be a {INPUT_TYPES[key]}")
+    
+    if key == "region" :
+        aws_regions = get_avalible_s3_regions()
+        if (value not in aws_regions) or (type(value) != str):
+            raise ValueError(f"'{key}' must be one of {aws_regions}.")
+    
+    s3_client_ = ["s3://", "s3n://", "s3a://"]
+    if key == "s3-staging-dir":
+        if not any([ value.startswith(p) for p in s3_client_ ]):
+            raise ValueError(f"'{key}' must be a valid s3 path startign with {s3_client_}.")
+    
+    if value is None or (type(value) == str and value.strip() in '') :
+        raise ValueError(f"'{key}' is not a valid value of {key}.")
+    
+    if key == 'spark-version':
+        if type(version.parse(value)) == version.LegacyVersion :
+            print("Warning: Is the spark version '{value}' specified valid? ")
+    
+    if key == 'stage':
+        if value not in ['dev','prod','stage','qa','test']:
+            print("Warning: 'stage' is meant to be one of ['dev','qa','prod']")
+    
+    
+
+def format_input( key, value):
+    """"""
+    if key in INPUT_TYPES:
+        value= INPUT_TYPES[key](value)
+    
+    if key == 'stage':
+        value = value.lower()
+    
+    if type(value) == str:
+        value = value.strip()
+    
+    return value
+
+
+def get_default_value(key):
+    return DEFAULT_CONFIG_TEMPLATE.get(key, "")
+
+
 @lru_cache()
 def get_config_attr(key, toml_path=DEFAULT_TOML_PATH):
     """Looks for a attribute in the project toml.
@@ -141,22 +209,22 @@ def get_config_attr(key, toml_path=DEFAULT_TOML_PATH):
     Returns:
 
     """
-
+    
     if not _pyproject_toml_exists(toml_path):
         cprint(f"No '{toml_path}' found.", "WARNING")
-    else:
-        conf = load_config()
-        if key not in conf:
-            cprint(f"No '{key}' found in config.", "WARNING")
-        elif conf[key] is None or conf[key] == "":
-            cprint(f"No '{key}' found in config.", "WARNING")
-        else:
-            return conf[key]
-
-    value = cinput(f"Select {key}", DEFAULT_CONFIG_TEMPLATE.get(key, ""))
-    if value is None or value == "":
-        ValueError(f"'{value}' is not a valid value for '{key}'")
-
+    
+    conf = load_config()
+    if not (conf.get(key) in [None,'','\n']) :
+        return conf[key]
+    
+    if len(conf) > 0 :
+        cprint(f"No valid '{key}' found in config.", "WARNING")
+    
+    default_value = get_default_value(key)
+    value = cinput(f"Select {key}", default_value)
+    value = format_input(key, value)
+    validate_input(key, value)
+    
     return value
 
 
@@ -180,29 +248,6 @@ def get_project_attributes(keys: list):
 
     Args:
       keys: list
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
-      keys: list:
 
     Returns:
 
@@ -330,7 +375,7 @@ def get_project_type(toml_path: str = DEFAULT_TOML_PATH):
 
     Args:
       toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      
+
     Returns:
 
     """
@@ -345,10 +390,6 @@ def _pyproject_toml_exists(pyproj_path: str = DEFAULT_TOML_PATH):
 
     Args:
       pyproj_path: str: (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
 
@@ -361,7 +402,6 @@ def _get_pyproject_toml(pyproj_path: str = DEFAULT_TOML_PATH) -> Dict[str, str]:
 
     Args:
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
       dict: Project toml param.
@@ -384,7 +424,7 @@ def _write_pyproject_toml(file_contents: dict, pyproj_path: str = DEFAULT_TOML_P
     Args:
       file_contents: dict:
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-
+    
     Returns:
 
     """
@@ -394,11 +434,13 @@ def _write_pyproject_toml(file_contents: dict, pyproj_path: str = DEFAULT_TOML_P
 
 def load_config():
     """Loads the pyemr config parameters from the project toml file."""
-    tml = _get_pyproject_toml()
-    if "tool" in tml:
-        if "pyemr" in tml["tool"]:
-            return tml["tool"]["pyemr"]
-
+    
+    if _pyproject_toml_exists():
+        tml = _get_pyproject_toml()
+        if "tool" in tml:
+            if "pyemr" in tml["tool"]:
+                return tml["tool"]["pyemr"]
+    
     return {}
 
 
@@ -472,7 +514,9 @@ def cprint(text, color="OKCYAN"):
     print(color_text(text, color))
 
 
-def init_pyemr_param(cluster_name, s3_stage_dir, stage, region):
+
+
+def init_pyemr_param( **kwargs ):
     """Append EMR pack parameters to the project toml.
 
     Args:
@@ -485,38 +529,34 @@ def init_pyemr_param(cluster_name, s3_stage_dir, stage, region):
     Returns:
 
     """
-
+    
+    # convert kwargs to toml key names
+    kwargs = { k.replace("_",'-'): v for k,v in kwargs.items() }
+    
+    # get pyemr config values 
     tml = _get_pyproject_toml()
-
-    if "tool" not in tml:
-        tml["tool"] = {}
-
-    if "pyemr" not in tml["tool"]:
-        tml["tool"]["pyemr"] = {}
-
-    if cluster_name:
-        tml["tool"]["pyemr"]["cluster-name"] = cluster_name
-
-    if s3_stage_dir:
-        tml["tool"]["pyemr"]["s3-staging-dir"] = s3_stage_dir
-
-    if stage:
-        tml["tool"]["pyemr"]["stage"] = stage
-
-    if region:
-        tml["tool"]["pyemr"]["region"] = region
-
-    for variable_name, default_value in DEFAULT_CONFIG_TEMPLATE.items():
-        if variable_name not in tml["tool"]["pyemr"]:
-            if variable_name in REQUIRED_PARAM:
-                value = cinput(variable_name, default_value)
+    tml['tool'] =tml.get('tool',{})
+    tool_pyemr_ = tml['tool'].get('pyemr',{})
+    
+    for key, default_value in DEFAULT_CONFIG_TEMPLATE.items():
+        if key in kwargs and (kwargs[key] is not None) and (kwargs[key]!=''):
+            value = kwargs[key]
+            value = format_input(key, value)
+            validate_input(key, value)
+            tool_pyemr_[key] = value
+            cprint(  f'{key}: ' + color_text(f'{value}', "OKGREEN") )
+        else:
+            if key in REQUIRED_PARAM:
+                value = cinput(key, default_value)
             else:
                 value = default_value
-            tml["tool"]["pyemr"][variable_name] = value
-
-    # print("[tool.pyemr]")
-    # print(tomlkit.dumps(tml["tool"]["pyemr"]))
-
+            
+            value = format_input(key, value)
+            validate_input(key, value)
+            value = format_input(key, value)
+            tool_pyemr_[key] = value
+    
+    tml['tool']['pyemr']  = tool_pyemr_
     _write_pyproject_toml(tml)
 
 
@@ -524,8 +564,8 @@ def add_dependencies(dependencies: list):
     """Add dependencies to the project toml file.
 
     Args:
-      dependencies: A list of pypi package names.
-      
+      dependencies: list: A list of pypi package names.
+
     Returns:
 
     """
@@ -641,17 +681,21 @@ def init_pyemr(project_name, cluster_name, s3_stage_dir, stage, region):
             "--python=>=3.7.1,<3.9",
             "-n",
             "--name",
-            project_name,
+            f"{project_name}",
             "--quiet",
         ] + dep
         with subprocess.Popen(args) as proc:
             proc.communicate()
-
+    
     # install default dependencies
-    # add_dependencies(DEFAULT_DEPENDENCIES)
+    add_dependencies(DEFAULT_DEPENDENCIES)
     add_scr_package()
-    init_pyemr_param(cluster_name, s3_stage_dir, stage, region)
+    init_pyemr_param(cluster_name=cluster_name, s3_staging_dir=s3_stage_dir, stage=stage, region=region)
     create_git_ignore()
+    
+    if not os.path.isfile("pyproject.toml"):
+        raise ValueError("Whoops... something went wrong. 'pyproject.toml' does not exist. Please report this on git. ")
+    
     # os.system("open pyproject.toml")
 
 
