@@ -45,8 +45,8 @@ def test_pyemr_python_docker(tmp_chdir, pexpect2):
     Returns:
 
     """
-    with pexpect2("pyemr python",1000) as ifthen:
-        ifthen("Select spark_version", "\n")
+    with pexpect2("pyemr python", 1000) as ifthen:
+        ifthen("Select spark-version", "\n")
         ifthen(">>>")
 
 
@@ -89,7 +89,7 @@ def test_pyemr_notebook_docker(tmp_chdir, pexpect2):
 
     """
     with pexpect2("pyemr notebook", 1000) as ifthen:
-        ifthen("Select spark_version", "\n")
+        ifthen("Select spark-version", "\n")
         ifthen("NotebookApp")
 
 
@@ -123,9 +123,14 @@ def test_pyemr_testing(tmp_chdir, pexpect2):
     Returns:
 
     """
-    with pexpect2("pyemr init asds asdsd asds sdsd sds") as ifthen:
-        ifthen(EOF)
-
+    
+    with pexpect2("pyemr init") as ifthen:
+        ifthen("Project Name", "\n")
+        ifthen("cluster-name", "\n")
+        ifthen("s3-staging-dir", "\n")
+        ifthen("stage", "\n")
+        ifthen("region", "\n")
+    
     assert os.path.isfile("./pyproject.toml")
 
     with pexpect2("pyemr test src/script.py", 1000) as ifthen:
