@@ -22,16 +22,42 @@ def test_init_param(tmp_chdir, pexpect2, uid):
     """
     toml_path = "./pyproject.toml"
     assert not os.path.isfile(toml_path)
-
-    with pexpect2(f"pyemr init {uid} {uid} {uid} dev {uid}") as ifthen:
-        assert ifthen(EOF)
-
+    
+    region = 'eu-west-1'
+    os.system(f"pyemr init {uid} {uid} s3://{uid} dev {region}")
+    
     toml = open(toml_path).read()
     assert os.path.isfile(toml_path)
     assert f'name = "{uid}"' in toml
-    assert f's3-staging-dir = "{uid}"' in toml
+    assert f's3-staging-dir = "s3://{uid}"' in toml
+    assert f'region = "{region}"' in toml
 
 
+
+def test_init_integer_param(tmp_chdir, pexpect2, ):
+    """
+
+    Args:
+      stdin:
+      pyemr:
+      tmp_chdir:
+      pexpect2:
+
+    Returns:
+
+    """
+    toml_path = "./pyproject.toml"
+    assert not os.path.isfile(toml_path)
+    
+    region = 'eu-west-1'
+    uid = 2313
+    os.system(f"pyemr init {uid} {uid} s3://{uid} dev {region}")
+    toml = open(toml_path).read()
+    assert os.path.isfile(toml_path)
+    assert f'name = "{uid}"' in toml
+    assert f's3-staging-dir = "s3://{uid}"' in toml
+    assert f'region = "{region}"' in toml
+
 def test_pyemr_add(tmp_chdir, pexpect2, uid):
     """
 
@@ -51,15 +77,17 @@ def test_pyemr_add(tmp_chdir, pexpect2, uid):
     toml_path = "./pyproject.toml"
     assert not os.path.isfile(toml_path)
 
-    with pexpect2("pyemr init", 300) as ifthen:
+    region = 'eu-west-1'
+
+    with pexpect2("pyemr init", 5) as ifthen:
         ifthen("Project Name", uid)
         ifthen("cluster-name", uid)
         ifthen("s3-staging-dir", f"s3://{uid}")
         ifthen("stage", "dev")
-        ifthen("region", "eu-west-1")
+        ifthen("region", region )
         assert ifthen(EOF)
-
-    with pexpect2("pyemr add cowsay==4.0") as ifthen:
+    
+    with pexpect2("pyemr add cowsay==4.0", 300) as ifthen:
         assert ifthen(EOF)
 
     assert os.path.isfile(toml_path)
@@ -67,3 +95,5 @@ def test_pyemr_add(tmp_chdir, pexpect2, uid):
     assert f'name = "{uid}"' in toml
     assert 'cowsay = "4.0"' in toml
     assert f's3-staging-dir = "s3://{uid}"' in toml
+    assert f'region = "{region}"' in toml
+
