@@ -15,7 +15,7 @@ def test_pyemr_start_notebook(tmp_chdir, pexpect2):
 
     """
     with pexpect2("pyemr notebook") as ifthen:
-        ifthen("Select spark_version", "\n")
+        ifthen("Select spark-version", "\n")
         ifthen("To access the notebook, open this file in a browser")
 
 
@@ -33,9 +33,9 @@ def test_compile_notebook(tmp_chdir, pexpect2, copy_to_tmp):
     """
 
     copy_to_tmp("write_dataframe.ipynb")
-    with pexpect2("pyemr init q w e dev t") as ifthen:
+    with pexpect2("pyemr init q w s3://42343 dev eu-west-1") as ifthen:
         assert ifthen(EOF)
-
+    
     with pexpect2("pyemr install_pyemr_kernel") as ifthen:
         ifthen("Done")
 
